@@ -12,6 +12,7 @@ from joblib import Parallel, delayed, wrap_non_picklable_objects
 from joblib.externals.loky import set_loky_pickler
 import numpy as np
 import pandas as pd
+import psutil
 from scipy.stats import norm as normal
 from tqdm import tqdm
 
@@ -64,7 +65,8 @@ def aso(
     num_comparisons: int
         Number of comparisons that the test is being used for. Is used to perform a Bonferroni correction.
     num_samples: int
-        Number of samples from the score distributions during every bootstrap iteration when estimating sigma.
+        DEPRECATED: Number of samples from the score distributions during every bootstrap iteration when estimating
+        sigma. Currently ignored, and will be deprecated in next major release.
     num_bootstrap_iterations: int
         Number of bootstrap iterations when estimating sigma.
     dt: float
@@ -89,13 +91,23 @@ def aso(
     assert (
         num_bootstrap_iterations > 0
     ), "num_samples must be positive, {} found.".format(num_bootstrap_iterations)
-    assert num_jobs > 0, "Number of jobs has to be at least 1, {} found.".format(
-        num_jobs
-    )
+    assert (
+        num_jobs > 0 or num_jobs == -1
+    ), "Number of jobs has to be at least 1 or -1, {} found.".format(num_jobs)
     assert (
         num_comparisons > 0
     ), "Number of comparisons has to be at least 1, {} found.".format(num_comparisons)
 
+    # Determine the maximum number of jobs possible
+    if num_jobs == -1:
+        num_jobs = psutil.cpu_count(logical=True)
+
+        if num_jobs is None:
+            warn(
+                "Number of available CPUs could not be determined, setting num_jobs=1."
+            )
+            num_jobs = 1
+
     # TODO: Remove in future version
     if num_samples != 1000:
         warn(
@@ -178,11 +190,12 @@ def multi_aso(
         Indicate whether Bonferroni correction should be applied to confidence level in order to adjust for the number
         of comparisons. Default is True.
     use_symmetry: bool
-        Use the fact that ASO(A, B, alpha) = 1 - ASO(B, A, alpha)
+        DEPRECATED: Use the fact that ASO(A, B, alpha) = 1 - ASO(B, A, alpha)
         `del Barrio et al. (2018) <https://arxiv.org/pdf/1705.01788.pdf>`_ to save half of the computations. Default is
-        True.
+        True. Currently ignored, and will be deprecated in next major release.
     num_samples: int
-        Number of samples from the score distributions during every bootstrap iteration when estimating sigma.
+        DEPRECATED: Number of samples from the score distributions during every bootstrap iteration when estimating
+        sigma. Currently ignored, and will be deprecated in next major release.
     num_bootstrap_iterations: int
         Number of bootstrap iterations when estimating sigma.
     dt: float
@@ -202,6 +215,20 @@ def multi_aso(
     Union[np.array, pd.DataFrame]
         2D numpy array or pandas Dataframe (if scores is dictionary and return_df=True) with result of ASO.
     """
+    assert (
+        num_jobs > 0 or num_jobs == -1
+    ), "Number of jobs has to be at least 1 or -1, {} found.".format(num_jobs)
+
+    # Determine the maximum number of jobs possible
+    if num_jobs == -1:
+        num_jobs = psutil.cpu_count(logical=True)
+
+        if num_jobs is None:
+            warn(
+                "Number of available CPUs could not be determined, setting num_jobs=1."
+            )
+            num_jobs = 1
+
     # TODO: Remove in future version
     if num_samples != 1000:
         warn(
